
[data-md-color-scheme="slate"] .md-header {
  background-color: #1E1E1E;
  color: #BDBDBD;
}

[data-md-color-scheme="slate"] .md-tabs {
  background-color: #1E1E1E;
  color: #BDBDBD;
}

/* Hide site name in header */
.md-header__title .md-header__topic:first-child {
  display: none;
}
